aboutsummaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
authorEugene Sandulenko2007-02-13 13:42:28 +0000
committerEugene Sandulenko2007-02-13 13:42:28 +0000
commitda7d8c9f35829184fcf16d60689b671fafee30d4 (patch)
treec1e8bf69c7e505c19d6c7c1169309d7328e9958b /common
parent731f1017c1452063a9b722c3f4601f12034f2d16 (diff)
downloadscummvm-rg350-da7d8c9f35829184fcf16d60689b671fafee30d4.tar.gz
scummvm-rg350-da7d8c9f35829184fcf16d60689b671fafee30d4.tar.bz2
scummvm-rg350-da7d8c9f35829184fcf16d60689b671fafee30d4.zip
Rename Common::GF_XXX to Common::ADGF_XXX
svn-id: r25545
Diffstat (limited to 'common')
-rw-r--r--common/advancedDetector.cpp4
-rw-r--r--common/advancedDetector.h6
2 files changed, 5 insertions, 5 deletions
diff --git a/common/advancedDetector.h b/common/advancedDetector.h
index abd974ff46..68d59c99f7 100644
--- a/common/advancedDetector.h
+++ b/common/advancedDetector.h
@@ -38,8 +38,8 @@ struct ADGameFileDescription {
};
enum ADGameFlags {
- GF_NO_FLAGS = 0,
- GF_DEMO = 1 << 31
+ ADGF_NO_FLAGS = 0,
+ ADGF_DEMO = 1 << 31
};
struct ADGameDescription {
@@ -58,7 +58,7 @@ struct ADGameDescription {
};
#define AD_TABLE_END_MARKER \
- { NULL, NULL, { { NULL, 0, NULL, 0 } }, Common::UNK_LANG, Common::kPlatformUnknown, Common::GF_NO_FLAGS }
+ { NULL, NULL, { { NULL, 0, NULL, 0 } }, Common::UNK_LANG, Common::kPlatformUnknown, Common::ADGF_NO_FLAGS }
struct ADObsoleteGameID {
const char *from;
diff --git a/common/advancedDetector.cpp b/common/advancedDetector.cpp
index f61a14ccae..856d10fc3c 100644
--- a/common/advancedDetector.cpp
+++ b/common/advancedDetector.cpp
@@ -135,13 +135,13 @@ static GameDescriptor toGameDescriptor(const ADGameDescription &g, const PlainGa
/**
* Generate a preferred target value as
* GAMEID-PLAFORM-LANG
* or (if GF_DEMO has been set)
* GAMEID-demo-PLAFORM-LANG
*/
static String generatePreferredTarget(const String &id, const ADGameDescription *desc) {
String res(id);
- if (desc->flags & GF_DEMO) {
+ if (desc->flags & ADGF_DEMO) {
res = res + "-demo";
}
@@ -135,13 +135,13 @@ static GameDescriptor toGameDescriptor(const ADGameDescription &g, const PlainGa
* Generate a preferred target value as
* GAMEID-PLAFORM-LANG
- * or (if GF_DEMO has been set)
+ * or (if ADGF_DEMO has been set)
* GAMEID-demo-PLAFORM-LANG
*/